# importing the data.
# please see read_multiple_files.R for details (here it is even easier because all the files are in the same directory)
setwd("~/Nos_Documents/Seb_work/Enseignements/Rcourse/data/FromStudents/FD/data/")
files2read <- list.files(pattern = "ninetysixwell_")
# 
for(myfile in files2read){
  varname <- gsub("ninetysixwell_", "", gsub(".csv","", myfile))
  print(varname)
  tmp <- read.csv2(file = myfile, stringsAsFactors = FALSE)
  rownames(tmp) <- tmp[,1] # rownames are in column 1 (??) so we are going to reassign the correct rownames...
  assign(varname, tmp[-1]) # ... and once it is done, removing the column
}
# 

# we are going to create a function to transform our 8x12 data into what is called a "long" format in which we will have 8x12= 96 lines.
# in this function we are going to have 2 loops
#  • one to scan the rows
#  • one to scan the colums

make_df_long <- function(mat_coord, mat_values){ #this function takes 2 arguments : a matrix of coordinates and a matrix of values
  # creating a empty data frame in which we are going to reorganised the data
  df_sample_coord_and_value_long <- data.frame()
  # setting the line counter
  row_index_long <- 0
  
  # nested loops
  for(r in 1:nrow(mat_coord)){ # loop1
    for(c in 1:ncol(mat_coord)){ #loop2
      
      # extracting  the sample id from mat_coord matrix at coordinates line 'r', column 'c'
      sample_id <- mat_coord[r,c]
      # extracting  for this sample id the corresponding value from mat_value matrix at coordinates line 'r', column 'c'
      thevalue <- mat_values[r,c]
      
      cat("ligne : ", r, "\tcolonne : ", c, "\n\tsample id" = sample_id, "\n\tassociated value = ", thevalue, "\n") #verbose : allow to check we're extracting what we want
      
      row_index_long <- row_index_long + 1 # incremanting the line counter
      
      # filling the data frame
      df_sample_coord_and_value_long[row_index_long, "row"] <- rownames(mat_coord)[r] #in col "row" we'll store the lines id
      df_sample_coord_and_value_long[row_index_long,"col"] <- rownames(mat_coord)[c] #in col "col" we'll store the col id
      df_sample_coord_and_value_long[row_index_long,"sample"] <- sample_id #in col "sample" we'll store the sample id
      df_sample_coord_and_value_long[row_index_long,"value"] <- thevalue #in col "value" we'll store the associated value
    }
  }
  return(df_sample_coord_and_value_long) #return the filled data.frame
}

# let's execute the function on the different tables from the different experiments
exp1_long <- make_df_long(mat_coord = exp1_sample_coord, mat_values = exp1_sample_values)
exp2_long <- make_df_long(mat_coord = exp2_sample_coord, mat_values = exp2_sample_values)
exp3_long <- make_df_long(mat_coord = exp3_sample_coord, mat_values = exp3_sample_values)
# -> explore the newly formed table !!

# combining the info from the different experiments
# add a column with the experiement id (!)
exp1_long$expId <- "exp1"
exp2_long$expId <- "exp2"
exp3_long$expId <- "exp3"

# use the rbind function to combine the different tables
all_exp_long <- rbind(exp1_long, exp2_long)
all_exp_long <- rbind(all_exp_long, exp3_long)

# check data structure
table(all_exp_long$expId)

# refactoring the sample (to avoid having the samples order like S_1, S_10, S_11... but having S_1, S_2, S_3... instead)
all_exp_long$sample <- factor(all_exp_long$sample, levels = paste("S", 1:32, sep = "_"))

# extracting from the table the information for a given sample 
# example sample "S_2
all_exp_long[all_exp_long$sample == "S_2",]

# Let's make some plots
# load the required packages
library(ggplot2)
library(gridExtra)

ggplot(all_exp_long, aes(x = sample, y = value))+
  geom_point()+
  theme_minimal()

ggplot(all_exp_long, aes(x = sample, y = value))+
  geom_point()+
  theme_minimal()+
  scale_y_log10() # better visualisation on the y-axis

ggplot(all_exp_long, aes(x = sample, y = value))+
  geom_point(aes(color = expId))+ # even better with the experiement id color-coded
  theme_minimal()+
  scale_y_log10()

ggplot(all_exp_long, aes(x = sample, y = value))+
  geom_point(aes(color = expId))+
  theme_minimal()+
  scale_y_log10()+
  facet_grid(~ expId) # the different experiement in different 'facets' of the graph

# representing the 96 well in balloon plots
# exp1
balloon_exp1 <- ggplot(all_exp_long[all_exp_long$expId == "exp1",] , aes(x = col, y = row))+
  geom_point(aes(size = log10(value), fill = sample), shape = 21, color = "black", alpha = .5)+
  theme_minimal()+
  theme(panel.grid.minor = element_blank())+
  geom_text(aes(label = sample), size=3, color = "black")+
  guides(fill=FALSE)+
  theme(panel.grid.minor = element_blank())+
  ggtitle("exp1")+
  scale_x_continuous(breaks = 1:12)
balloon_exp1

# exp2
balloon_exp2 <- ggplot(all_exp_long[all_exp_long$expId == "exp2",] , aes(x = col, y = row))+
  geom_point(aes(size = log10(value), fill = sample), shape = 21, color = "black", alpha = .5)+
  theme_minimal()+
  theme(panel.grid.minor = element_blank())+
  geom_text(aes(label = sample), size=3, color = "black")+
  guides(fill=FALSE)+
  theme(panel.grid.minor = element_blank())+
  ggtitle("exp2")+
  scale_x_continuous(breaks = 1:12)
balloon_exp2

# exp3
balloon_exp3 <- ggplot(all_exp_long[all_exp_long$expId == "exp3",] , aes(x = col, y = row))+
  geom_point(aes(size = log10(value), fill = sample), shape = 21, color = "black", alpha = .5)+
  theme_minimal()+
  theme(panel.grid.minor = element_blank())+
  geom_text(aes(label = sample), size=3, color = "black")+
  guides(fill=FALSE)+
  theme(panel.grid.minor = element_blank())+
  ggtitle("exp3")+
  scale_x_continuous(breaks = 1:12)
balloon_exp3

# combining the 3 plots in 1
grid.arrange(balloon_exp1, balloon_exp2, balloon_exp3, nrow = 3, ncol=1)

# There plenty of other things we can do. But first we should know what is the biological question !!
